==> ejc-bfyjerp-impl-3.0.0-20241120.022203-43-sources.jar: com/ejianc/business/oa/bean/SealUseEntity.java <==
package com.ejianc.business.oa.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 用印申请
 * 
 * @author generator
 * 
 */
 @TableName("ejc_oa_seal_use")
public class SealUseEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="bill_state")
    private Integer billState; // 单据状态：0-自由态，1-已提交，2-审批中，3-审批通过，4-审批不通过
    @TableField(value="employee_id")
    private Long employeeId; // 保管人id
    @TableField(value="employee_name")
    private String employeeName; // 保管人name
    @TableField(value="date")
    private Date date; // 用印日期
    @TableField(value="name")
    private String name; // 刻章名称
    @TableField(value="use")
    private String use; // 用途
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_code")
    private String orgCode; // 组织编码
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 项目所属组织
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 项目所属组织编码
    @TableField(value="seal_unit_id")
    private Long sealUnitId; // 加印单位id
    @TableField(value="seal_unit_name")
    private String sealUnitName; // 加印单位name
    @TableField(value="seal_type_id")
    private Long sealTypeId; // 用印类别id
    @TableField(value="seal_type_name")
    private String sealTypeName; // 用印类别name
    @TableField(value="doc_num")
    private Integer docNum; // 文件份数
    @TableField(value="doc_type_id")
    private Long docTypeId; // 文件类别id
    @TableField(value="doc_type_name")
    private String docTypeName; // 文件类别name
    @TableField(value="lender_flag")
    private String lenderFlag; // 是否外借
    
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Date getDate() {
        return date;
    }

    public void setDate(Date date) {
        this.date = date;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getUse() {
        return use;
    }

    public void setUse(String use) {
        this.use = use;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public Long getSealUnitId() {
        return sealUnitId;
    }

    public void setSealUnitId(Long sealUnitId) {
        this.sealUnitId = sealUnitId;
    }
    public String getSealUnitName() {
        return sealUnitName;
    }

    public void setSealUnitName(String sealUnitName) {
        this.sealUnitName = sealUnitName;
    }
    public Long getSealTypeId() {
        return sealTypeId;
    }

    public void setSealTypeId(Long sealTypeId) {
        this.sealTypeId = sealTypeId;
    }
    public String getSealTypeName() {
        return sealTypeName;
    }

    public void setSealTypeName(String sealTypeName) {
        this.sealTypeName = sealTypeName;
    }
    public Integer getDocNum() {
        return docNum;
    }

    public void setDocNum(Integer docNum) {
        this.docNum = docNum;
    }
    public Long getDocTypeId() {
        return docTypeId;
    }

    public void setDocTypeId(Long docTypeId) {
        this.docTypeId = docTypeId;
    }
    public String getDocTypeName() {
        return docTypeName;
    }

    public void setDocTypeName(String docTypeName) {
        this.docTypeName = docTypeName;
    }
    public String getLenderFlag() {
        return lenderFlag;
    }

    public void setLenderFlag(String lenderFlag) {
        this.lenderFlag = lenderFlag;
    }
    
}

==> ejc-bfyjerp-impl-3.0.0-20251216.084033-314-sources.jar: com/ejianc/business/oa/bean/SealUseEntity.java <==
package com.ejianc.business.oa.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 用印申请
 * 
 * @author generator
 * 
 */
 @TableName("ejc_oa_seal_use")
public class SealUseEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="bill_state")
    private Integer billState; // 单据状态：0-自由态，1-已提交，2-审批中，3-审批通过，4-审批不通过
    @TableField(value="employee_id")
    private Long employeeId; // 保管人id
    @TableField(value="employee_name")
    private String employeeName; // 保管人name
    @TableField(value="date")
    private Date date; // 用印日期
    @TableField(value="name")
    private String name; // 刻章名称
    @TableField(value="purpose")
    private String purpose; // 用途
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_code")
    private String orgCode; // 组织编码
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 项目所属组织
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 项目所属组织编码
    @TableField(value="seal_unit_id")
    private Long sealUnitId; // 加印单位id
    @TableField(value="seal_unit_name")
    private String sealUnitName; // 加印单位name
    @TableField(value="seal_type_id")
    private Long sealTypeId; // 用印类别id
    @TableField(value="seal_type_name")
    private String sealTypeName; // 用印类别name
    @TableField(value="doc_num")
    private Integer docNum; // 文件份数
    @TableField(value="doc_type_id")
    private Long docTypeId; // 文件类别id
    @TableField(value="doc_type_name")
    private String docTypeName; // 文件类别name
    @TableField(value="lender_flag")
    private String lenderFlag; // 是否外借
    
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Date getDate() {
        return date;
    }

    public void setDate(Date date) {
        this.date = date;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getPurpose() {
        return purpose;
    }

    public void setPurpose(String purpose) {
        this.purpose = purpose;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public Long getSealUnitId() {
        return sealUnitId;
    }

    public void setSealUnitId(Long sealUnitId) {
        this.sealUnitId = sealUnitId;
    }
    public String getSealUnitName() {
        return sealUnitName;
    }

    public void setSealUnitName(String sealUnitName) {
        this.sealUnitName = sealUnitName;
    }
    public Long getSealTypeId() {
        return sealTypeId;
    }

    public void setSealTypeId(Long sealTypeId) {
        this.sealTypeId = sealTypeId;
    }
    public String getSealTypeName() {
        return sealTypeName;
    }

    public void setSealTypeName(String sealTypeName) {
        this.sealTypeName = sealTypeName;
    }
    public Integer getDocNum() {
        return docNum;
    }

    public void setDocNum(Integer docNum) {
        this.docNum = docNum;
    }
    public Long getDocTypeId() {
        return docTypeId;
    }

    public void setDocTypeId(Long docTypeId) {
        this.docTypeId = docTypeId;
    }
    public String getDocTypeName() {
        return docTypeName;
    }

    public void setDocTypeName(String docTypeName) {
        this.docTypeName = docTypeName;
    }
    public String getLenderFlag() {
        return lenderFlag;
    }

    public void setLenderFlag(String lenderFlag) {
        this.lenderFlag = lenderFlag;
    }
    
}
